package com.gyee.runeconomy.service.monitor;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.gyee.runeconomy.dto.AlarmDataParser;
import com.gyee.runeconomy.init.CacheContext;
import com.gyee.runeconomy.model.auto.ProBasicEquipment;
import com.gyee.runeconomy.model.vo.PoliceVo;
import com.gyee.runeconomy.service.EarlyWarning.ApiClient;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class AlarmService {

    ApiClient client = new ApiClient();

    public List<PoliceVo.AlarmDetails> Alarm(String type,String wtid) throws Exception {
        // 获取当天零点时间
        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.HOUR_OF_DAY, 0);
        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);
        calendar.set(Calendar.MILLISECOND, 0);
        Date startDate = calendar.getTime();

        // 获取当前时间
        Date endDate = new Date();

        // 格式化时间为字符串
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String startTime = sdf.format(startDate);
        String endTime = sdf.format(endDate);

        List<PoliceVo.AlarmDetails> list = new ArrayList<>();

        List<ProBasicEquipment> equipments = CacheContext.wtls.stream()
                .filter(a -> wtid.equals(a.getId())).collect(Collectors.toList());

        String modelId = "WT2000D121H85";
        String station = "NX_FGS_HA_FDC_STA";
        if (equipments.size() > 0) {
            modelId = equipments.get(0).getModelId();
            station = equipments.get(0).getWindpowerstationId();
        }


//        startTime = "2024-12-12 00:00:00";
        String result = client.getgzFromApi(
                startTime,
                endTime,
                "windturbine",
                station,
                wtid,
                "",
                modelId,
                "windturbine",
                type,
                "",
                "",
                "1",
                "20"
        );


        // 解析预警数据
        try {
            // 调用parseJson方法解析JSON
            PoliceVo policeVo = parseJson(result);

            if (policeVo != null) {

                // 输出解析后的对象，检查内容
                List<PoliceVo.AlarmDetails> alarmList1 = policeVo.getData().getLs();
                for (PoliceVo.AlarmDetails alarm1 : alarmList1) {
                    list.add(alarm1);
                }
            }
        } catch (IOException e){
            e.printStackTrace();
        }

        return list;
    }


    public static PoliceVo parseJson(String json) throws IOException {
        // 创建ObjectMapper实例
        ObjectMapper objectMapper = new ObjectMapper();

        // 设置ObjectMapper来忽略未知的属性
        objectMapper.configure(com.fasterxml.jackson.databind.DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);

        // 解析JSON并转换为PoliceVo对象
        PoliceVo policeVo = objectMapper.readValue(json, PoliceVo.class);

        return policeVo;
    }
}
